==> blesta-5.10.2.zip: blesta/plugins/webhooks/language/da_dk/webhooks_webhooks.php <==
<?php
/**
 * Webhooks Webhooks
 *
 * @package blesta
 * @subpackage blesta.language.da_dk
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['WebhooksWebhooks.getMethods.json'] = 'JSON';
$lang['WebhooksWebhooks.getMethods.post'] = 'POST';
$lang['WebhooksWebhooks.getMethods.get'] = 'FÅ';
$lang['WebhooksWebhooks.getTypes.type_outgoing'] = 'Udgående';
$lang['WebhooksWebhooks.getTypes.type_incoming'] = 'Indkommende';
$lang['WebhooksWebhooks.!error.fields[][parameter].length'] = 'Navnet på parameteren kan ikke overstige 255 tegn.';
$lang['WebhooksWebhooks.!error.fields[][parameter].empty'] = 'Feltets parameter kan ikke være tom.';
$lang['WebhooksWebhooks.!error.fields[][field].length'] = 'Feltets navn kan ikke overstige 255 tegn.';
$lang['WebhooksWebhooks.!error.fields[][field].empty'] = 'Feltets navn kan ikke være tomt.';
$lang['WebhooksWebhooks.!error.method.valid'] = 'Vælg venligst en gyldig metode.';
$lang['WebhooksWebhooks.!error.type.valid'] = 'Vælg venligst en gyldig type.';
$lang['WebhooksWebhooks.!error.event.exists'] = 'Den angivne begivenhed findes ikke.';
$lang['WebhooksWebhooks.!error.callback.length'] = 'Tilbagekaldelsen kan ikke overstige 255 tegn.';
$lang['WebhooksWebhooks.!error.callback.empty'] = 'Indtast venligst et gyldigt tilbagekald.';
$lang['WebhooksWebhooks.!error.callback.exists'] = 'Der findes allerede et webhook af denne type med dette callback.';
$lang['WebhooksWebhooks.!error.company_id.exists'] = 'Den angivne virksomhed eksisterer ikke.';

==> blesta-5.11.4.zip: blesta/plugins/webhooks/language/da_dk/webhooks_webhooks.php <==
<?php
/**
 * Webhooks Webhooks
 *
 * @package blesta
 * @subpackage blesta.language.da_dk
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['WebhooksWebhooks.getMethods.json'] = 'JSON';
$lang['WebhooksWebhooks.getMethods.post'] = 'POST';
$lang['WebhooksWebhooks.getMethods.get'] = 'FÅ';
$lang['WebhooksWebhooks.getTypes.type_outgoing'] = 'Udgående';
$lang['WebhooksWebhooks.getTypes.type_incoming'] = 'Indkommende';
$lang['WebhooksWebhooks.!error.fields[][parameter].length'] = 'Navnet på parameteren kan ikke overstige 255 tegn.';
$lang['WebhooksWebhooks.!error.fields[][parameter].empty'] = 'Feltets parameter kan ikke være tom.';
$lang['WebhooksWebhooks.!error.fields[][field].length'] = 'Feltets navn kan ikke overstige 255 tegn.';
$lang['WebhooksWebhooks.!error.fields[][field].empty'] = 'Feltets navn kan ikke være tomt.';
$lang['WebhooksWebhooks.!error.method.valid'] = 'Vælg venligst en gyldig metode.';
$lang['WebhooksWebhooks.!error.type.valid'] = 'Vælg venligst en gyldig type.';
$lang['WebhooksWebhooks.!error.event.exists'] = 'Den angivne begivenhed findes ikke.';
$lang['WebhooksWebhooks.!error.callback.length'] = 'Tilbagekaldelsen kan ikke overstige 255 tegn.';
$lang['WebhooksWebhooks.!error.callback.empty'] = 'Indtast venligst et gyldigt tilbagekald.';
$lang['WebhooksWebhooks.!error.callback.exists'] = 'Der findes allerede et webhook af denne type med dette callback.';
$lang['WebhooksWebhooks.!error.company_id.exists'] = 'Den angivne virksomhed eksisterer ikke.';
$lang['WebhooksWebhooks.getMethods.put_json'] = 'PUT JSON';
$lang['WebhooksWebhooks.getMethods.post_json'] = 'POST JSON';
$lang['WebhooksWebhooks.getMethods.put'] = 'PUT';
$lang['WebhooksWebhooks.!error.events[].exists'] = 'Den angivne begivenhed findes ikke.';
